==> haskell-lsp1.4-1.4.0.0-133-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp1.4.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp
version:              1.4.0.0
visibility:           public
id:                   lsp-1.4.0.0-JVZ2VdEkXDH6Jz7Md2CcVn
key:                  lsp-1.4.0.0-JVZ2VdEkXDH6Jz7Md2CcVn
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:             Haskell library for the Microsoft Language Server Protocol
description:
    An implementation of the types, and basic message server to
    allow language implementors to support the Language Server
    Protocol for their specific language.

    An example of this is for Haskell via the Haskell Language
    Server, at https://github.com/haskell/haskell-language-server

category:             Development
abi:                  0ffaae356daeb5fd104f7ad74a5a2d55
exposed:              True
exposed-modules:
    Language.LSP.Diagnostics, Language.LSP.Server,
    Language.LSP.Types from lsp-types-1.4.0.1-V2J3nQZTHXDPUbF1UtNZo:Language.LSP.Types,
    Language.LSP.Types.Capabilities from lsp-types-1.4.0.1-V2J3nQZTHXDPUbF1UtNZo:Language.LSP.Types.Capabilities,
    Language.LSP.Types.Lens from lsp-types-1.4.0.1-V2J3nQZTHXDPUbF1UtNZo:Language.LSP.Types.Lens,
    Language.LSP.VFS from lsp-types-1.4.0.1-V2J3nQZTHXDPUbF1UtNZo:Language.LSP.VFS

hidden-modules:
    Language.LSP.Server.Core Language.LSP.Server.Control
    Language.LSP.Server.Processing

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lsp-1.4.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lsp-1.4.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lsp-1.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp1.4
hs-libraries:         HSlsp-1.4.0.0-JVZ2VdEkXDH6Jz7Md2CcVn
depends:
    aeson-2.1.2.1-5ZyQo9G6Ms46oZtaJgJtcb
    async-2.2.5-HIvtQdOwlf5Hsyin6u1n7Q
    attoparsec-0.14.4-8RYxJQa7MEjKmC3I11Us4k base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi exceptions-0.10.5
    hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    hslogger-1.3.1.2-7cqGvFW2jLnLcroti46V3f
    lens-5.2.3-9GV2xnL92otDGMRfTuRDyv
    lsp-types-1.4.0.1-V2J3nQZTHXDPUbF1UtNZo mtl-2.2.2
    network-uri-2.6.4.2-EDr74t9h07L15oCNeDNFfl
    random-1.2.1.2-2GxRLB29YjZ5Hmc9ZOWGpv
    scientific-0.3.7.0-BkypiqTAkpN3suN2c81wMx
    sorted-list-0.2.2.0-3PKg8r9fLwKFsBj8pkAdRm stm-2.5.1.0 text-2.0.2
    time-1.12.2 transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX
    uuid-1.3.16-872C2ncsprsByedHsPUft7

haddock-interfaces:   /usr/share/doc/haskell-lsp1.4/html/lsp.haddock
haddock-html:         /usr/share/doc/haskell-lsp1.4/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lsp1.4-1.4.0.0-135-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp1.4.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lsp
version:              1.4.0.0
visibility:           public
id:                   lsp-1.4.0.0-CLtOe1RM60yAp81SIIjIKR
key:                  lsp-1.4.0.0-CLtOe1RM60yAp81SIIjIKR
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:             Haskell library for the Microsoft Language Server Protocol
description:
    An implementation of the types, and basic message server to
    allow language implementors to support the Language Server
    Protocol for their specific language.

    An example of this is for Haskell via the Haskell Language
    Server, at https://github.com/haskell/haskell-language-server

category:             Development
abi:                  8615f4caf00fe08f1f8960073d6e2870
exposed:              True
exposed-modules:
    Language.LSP.Diagnostics, Language.LSP.Server,
    Language.LSP.Types from lsp-types-1.4.0.1-IBJPB4MShXPCZOTJtiVNOs:Language.LSP.Types,
    Language.LSP.Types.Capabilities from lsp-types-1.4.0.1-IBJPB4MShXPCZOTJtiVNOs:Language.LSP.Types.Capabilities,
    Language.LSP.Types.Lens from lsp-types-1.4.0.1-IBJPB4MShXPCZOTJtiVNOs:Language.LSP.Types.Lens,
    Language.LSP.VFS from lsp-types-1.4.0.1-IBJPB4MShXPCZOTJtiVNOs:Language.LSP.VFS

hidden-modules:
    Language.LSP.Server.Core Language.LSP.Server.Control
    Language.LSP.Server.Processing

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lsp-1.4.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lsp-1.4.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lsp-1.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp1.4
hs-libraries:         HSlsp-1.4.0.0-CLtOe1RM60yAp81SIIjIKR
depends:
    aeson-2.1.2.1-7NKMY9av0haL3nHVKphSJj
    async-2.2.5-HIvtQdOwlf5Hsyin6u1n7Q
    attoparsec-0.14.4-8RYxJQa7MEjKmC3I11Us4k base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi exceptions-0.10.5
    hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    hslogger-1.3.1.2-7cqGvFW2jLnLcroti46V3f
    lens-5.2.3-4nDp1u1qKC5FV2ww18Mx1
    lsp-types-1.4.0.1-IBJPB4MShXPCZOTJtiVNOs mtl-2.2.2
    network-uri-2.6.4.2-EDr74t9h07L15oCNeDNFfl
    random-1.2.1.2-2GxRLB29YjZ5Hmc9ZOWGpv
    scientific-0.3.7.0-BkypiqTAkpN3suN2c81wMx
    sorted-list-0.2.2.0-3PKg8r9fLwKFsBj8pkAdRm stm-2.5.1.0 text-2.0.2
    time-1.12.2 transformers-0.5.6.2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX
    uuid-1.3.16-872C2ncsprsByedHsPUft7

haddock-interfaces:   /usr/share/doc/haskell-lsp1.4/html/lsp.haddock
haddock-html:         /usr/share/doc/haskell-lsp1.4/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
